SystemOrganization addCategory: #ConfigurationOfEpicea!

Object subclass: #ConfigurationOfEpicea
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfEpicea'!

!ConfigurationOfEpicea commentStamp: 'MartinDias 2/11/2014 16:29' prior: 0!
I am a Metacello configuration for Epicea.

Epicea is a tool with a model for representing code history enriched with IDE events.

Look for examples in my class-side.


Load with: 

(ConfigurationOfEpicea project version: #stable) load.!

!ConfigurationOfEpicea class methodsFor: 'development support' stamp: 'MartinDias 8/13/2013 14:02'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfEpicea class methodsFor: 'private' stamp: 'MartinDias 8/13/2013 14:02'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfEpicea class methodsFor: 'catalog' stamp: 'MartinDias 8/18/2015 13:50'!
catalogContactInfo
	^ 'http://tinchodias.github.io'! !

!ConfigurationOfEpicea class methodsFor: 'catalog' stamp: 'MartinDias 8/18/2015 13:52'!
catalogDescription
	^ 'Epicea is a tool that records code changes enriched with IDE events.

Epicea extends and could replace the traditional .changes logging mechanism, where the recorded code changes are incomplete and are not properly reified and thus it can be difficult to recover lost code after an image crash.'! !

!ConfigurationOfEpicea class methodsFor: 'catalog' stamp: 'MartinDias 8/18/2015 13:55'!
catalogKeyClassesAndExample
	^ 'EpMonitor is a singleton instance that subscribes to System announcements when enabled.
EpEvent is the abstract superclass of all system events (including code changes) that are recorded by Epicea.'! !

!ConfigurationOfEpicea class methodsFor: 'catalog' stamp: 'MartinDias 8/18/2015 13:53'!
catalogKeywords
	^ { 'system event recording'. 'code change'. 'fine-grained'. 'history'. 'fileout'. 'changeset' }! !

!ConfigurationOfEpicea class methodsFor: 'private' stamp: 'MartinDias 8/13/2013 14:02'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfEpicea class methodsFor: 'private' stamp: 'MartinDias 8/13/2013 14:02'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfEpicea class methodsFor: 'metacello tool support' stamp: 'MartinDias 8/13/2013 14:02'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfEpicea class methodsFor: 'loading' stamp: 'MartinDias 8/13/2013 14:02'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfEpicea class methodsFor: 'loading' stamp: 'MartinDias 8/13/2013 14:02'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfEpicea class methodsFor: 'loading' stamp: 'MartinDias 8/13/2013 14:02'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfEpicea class methodsFor: 'loading' stamp: 'MartinDias 1/23/2015 13:47'!
loadStable
	"Load the #loadStable version defined for this platform. "

	"self loadStable"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfEpicea class methodsFor: 'accessing' stamp: 'MartinDias 8/13/2013 14:02'!
project

	^self new project! !

!ConfigurationOfEpicea class methodsFor: 'development support' stamp: 'MartinDias 8/13/2013 14:02'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/10/2013 23:44'!
baseline10: spec
	<version: '1.0-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec
				repository: self mainRepositoryUrlString;
				package: 'Ombu' with: [ spec requires: 'Phexample' ];
				package: 'Epicea' with: [ spec requires: #(Ombu) ].
				
			self baseline10Phexample: spec.

			spec group: 'default' with: #(Epicea) ]! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/17/2013 14:43'!
baseline10Phexample: spec
	spec 
		project: 'Phexample' 
		with: [
			spec
				className: 'ConfigurationOfPhexample';
				versionString: #'bleedingEdge';
				repository: 'http://www.smalltalkhub.com/mc/Phexample/Phexample/main' ]! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/17/2013 14:42'!
baseline13: spec
	<version: '1.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.
		self baseline10Phexample: spec.
		self baseline13STON: spec.
		spec 
			package: 'Ombu' with: [
				spec requires: #('Phexample' 'STON'). ];
			package: 'Epicea' with: [
				spec requires: #(#Ombu ). ].
		spec group: 'default' with: #(#Epicea ). ].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/17/2013 15:05'!
baseline13STON: spec
	spec 
		project: 'STON' 
		with: [
			spec
				className: 'ConfigurationOfSton';
				versionString: #'bleedingEdge';
				repository: 'http://ss3.gemtalksystems.com/ss/STON' ].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 10/22/2013 19:44'!
baseline14: spec
	<version: '1.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.
		self baseline10Phexample: spec.
		self baseline13STON: spec.
		spec 
			package: 'Ombu' with: [
				spec requires: #('STON'). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ].
		spec group: 'default' with: #(Epicea). ].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 2/10/2014 13:33'!
baseline20: spec
	<version: '2.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.
		self baseline13STON: spec.
	
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ];
			package: 'EpiceaExamples' with: [
				spec requires: #(Epicea). ].
		spec group: 'default' with: #(Epicea). ].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 3/27/2014 02:39'!
baseline33: spec
	<version: '3.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version33PostLoad.
				
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ];
			package: 'EpiceaExamples' with: [
				spec requires: #(Epicea). ].

		spec group: 'default' with: #(Epicea). ].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 6/5/2014 17:17'!
baseline41: spec
	<version: '4.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version41PostLoad.
				
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ];
			package: 'EpiceaExamples' with: [
				spec requires: #(Epicea). ].

		spec group: 'default' with: #(Epicea). ].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 10/3/2014 14:07'!
baseline42: spec
	<version: '4.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version41PostLoad.
				
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaExamples' with: [
				spec requires: #(Epicea) ].

		spec group: 'default' with: #(Epicea). ].
	
	spec for: #'pharo3.0.x' do: [		
		spec 
			package: 'EpiceaInPharo30';
			package: 'Epicea' with: [
				spec requires: #(Ombu EpiceaInPharo30) ].
	].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 10/30/2014 16:15'!
baseline43: spec
	<version: '4.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version41PostLoad.
				
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ].

		spec group: 'default' with: #(EpiceaKomitter). ].
	
	spec for: #'pharo3.0.x' do: [		
		spec 
			package: 'EpiceaInPharo30';
			package: 'Epicea' with: [
				spec requires: #(Ombu EpiceaInPharo30) ].
	].			
			
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 12/12/2014 15:39'!
baseline46: spec
	"Preparing for integration"
	<version: '4.6-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ].

		spec group: 'default' with: #(Epicea). ].
	
	spec for: #'pharo3.0.x' do: [		
		spec 
			package: 'EpiceaInPharo30';
			package: 'Epicea' with: [
				spec requires: #(Ombu EpiceaInPharo30) ].
	].			
			
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 1/13/2015 19:36'!
baseline48: spec
	<version: '4.8-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaTriggering' with: [
				spec requires: #(Epicea) ].


		spec group: 'default' with: #(Epicea).
		spec group: 'triggering' with: #(EpiceaTriggering) ].
	
	spec for: #'pharo3.0.x' do: [		
		spec 
			package: 'EpiceaInPharo30';
			package: 'Epicea' with: [
				spec requires: #(Ombu EpiceaInPharo30) ].
	].			
			
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 7/7/2015 16:40'!
baseline50: spec
	<version: '5.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec
			postLoadDoIt: #version50PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaTriggering' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ].

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'triggering' with: #(EpiceaTriggering EpiceaInPharo40) ].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"
		
		spec group: 'default' overrides: #(Epicea).
		spec group: 'triggering' overrides: #(EpiceaTriggering Epicea) ].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 7/10/2015 10:59'!
baseline51: spec
	<version: '5.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec postLoadDoIt: #version50PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ].		

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'triggering' with: #(EpiceaInPharo40). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50).
		spec group: 'triggering' overrides: #(EpiceaInPharo50). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaKomitter).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 7/14/2015 10:04'!
baseline54: spec
	<version: '5.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec postLoadDoIt: #version54PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ].		

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'triggering' with: #(EpiceaInPharo40). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50).
		spec group: 'triggering' overrides: #(EpiceaInPharo50). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaKomitter).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/9/2015 21:46'!
baseline59: spec
	<version: '5.9-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec postLoadDoIt: #version59PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ].		

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'triggering' with: #(EpiceaInPharo40). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50).
		spec group: 'triggering' overrides: #(EpiceaInPharo50). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaKomitter).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/14/2015 12:42'!
baseline60: spec
	<version: '6.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ].		

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'triggering' with: #(EpiceaInPharo40). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50).
		spec group: 'triggering' overrides: #(EpiceaInPharo50). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaKomitter).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MD 9/21/2015 17:36'!
baseline61: spec
	<version: '6.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Hiedra';
			package: 'EpiceaHiedra' with: [
				spec requires: #(Epicea Hiedra) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ].		

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'triggering' with: #(EpiceaInPharo40). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50).
		spec group: 'triggering' overrides: #(EpiceaInPharo50). "Kept only for backward-compatibility"
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaKomitter).
		spec group: 'hiedra' with: #(EpiceaInPharo50 EpiceaHiedra).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 10/22/2015 15:34'!
baseline64: spec
	<version: '6.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.
		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Hiedra';
			package: 'EpiceaHiedra' with: [
				spec requires: #(Epicea Hiedra) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaBenchmarks' with: [ 
				spec requires: #(Epicea SMark) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ].		

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50).
		spec group: 'benchmarks' with: #(EpiceaInPharo50 EpiceaBenchmarks).
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaKomitter).
		spec group: 'hiedra' with: #(EpiceaInPharo50 EpiceaHiedra).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 10/16/2015 15:52'!
baseline64SMark: spec
	spec
		project: 'SMark'
		with:
			[ spec
				className: 'ConfigurationOfSMark';
				versionString: #development;
				file: 'ConfigurationOfSMark';
				repository: 'http://smalltalkhub.com/mc/StefanMarr/SMark/main' ].
"	spec
		package: 'SMark-Jenkins'
		with:
			[ spec
				repository: 'http://smalltalkhub.com/mc/ClementBera/classic-bench/main';
				requires: 'SMark' ]"! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MD 11/9/2015 21:57'!
baseline65: spec
	<version: '6.5-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.
		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Hiedra';
			package: 'EpiceaHiedra' with: [
				spec requires: #(Epicea Hiedra) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaBenchmarks' with: [ 
				spec requires: #(Epicea SMark) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaSUnit' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ].		

		spec group: 'default' with: #(EpiceaInPharo40).
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50).
		spec group: 'benchmarks' with: #(EpiceaInPharo50 EpiceaBenchmarks).
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaKomitter).
		spec group: 'hiedra' with: #(EpiceaInPharo50 EpiceaHiedra).
		spec group: 'sunit' with: #(EpiceaInPharo50 EpiceaSUnit).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 11/12/2015 14:44'!
baseline66: spec
	<version: '6.6-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.
		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaTests' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaBenchmarks' with: [ 
				spec requires: #(EpiceaTests SMark) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(EpiceaTests) ];
			package: 'EpiceaSUnit' with: [
				spec requires: #(EpiceaTests) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(Epicea) ];
			package: 'Hiedra';
			package: 'EpiceaHiedra' with: [
				spec requires: #(Epicea Hiedra) ].

		spec group: 'default' with: #(EpiceaInPharo40 EpiceaTests).
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaTests EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50 EpiceaTests).
		spec group: 'core' overrides: #(EpiceaInPharo50).
		spec group: 'benchmarks' with: #(EpiceaInPharo50 EpiceaTests EpiceaBenchmarks).
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaTests EpiceaKomitter).
		spec group: 'hiedra' with: #(EpiceaInPharo50 EpiceaTests EpiceaHiedra).
		spec group: 'sunit' with: #(EpiceaInPharo50 EpiceaTests EpiceaSUnit).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 12/2/2015 17:11'!
baseline71: spec
	<version: '7.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.
		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaBrowsers' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaTests' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaBrowsersTests' with: [
				spec requires: #(EpiceaBrowsers EpiceaTests) ];
			package: 'EpiceaBenchmarks' with: [ 
				spec requires: #(EpiceaBrowsersTests SMark) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(EpiceaBrowsersTests) ];
			package: 'EpiceaSUnit' with: [
				spec requires: #(EpiceaBrowsersTests) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(EpiceaBrowsers) ];
			package: 'EpiceaInPharo50' with: [
				spec requires: #(EpiceaBrowsers) ];
			package: 'Hiedra';
			package: 'EpiceaHiedra' with: [
				spec requires: #(EpiceaBrowsers Hiedra) ].

		spec group: 'default' with: #(EpiceaInPharo40 EpiceaBrowsersTests).
		spec group: 'komitter' with: #(EpiceaInPharo40 EpiceaBrowsersTests EpiceaKomitter).
	].

	spec for: #'pharo5.x' do: [
		spec package: 'Ombu' overrides: [
			spec requires: #() ]. "Ston is integrated in Pharo 50"

		spec group: 'default' overrides: #(EpiceaInPharo50 EpiceaBrowsersTests).
		spec group: 'core' overrides: #(EpiceaInPharo50).
		spec group: 'benchmarks' with: #(EpiceaInPharo50 EpiceaBrowsersTests EpiceaBenchmarks).
		spec group: 'komitter' with: #(EpiceaInPharo50 EpiceaBrowsersTests EpiceaKomitter).
		spec group: 'hiedra' with: #(EpiceaInPharo50 EpiceaBrowsersTests EpiceaHiedra).
		spec group: 'sunit' with: #(EpiceaInPharo50 EpiceaBrowsersTests EpiceaSUnit).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 12/3/2015 17:42'!
baseline71p4: spec
	<version: '7.1.p4-baseline'>
	"Specialized baseline for Pharo 4"

	spec for: #'pharo4.x' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.
		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaBrowsers' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaTests' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaBrowsersTests' with: [
				spec requires: #(EpiceaBrowsers EpiceaTests) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(EpiceaBrowsers) ].

		spec group: 'default' with: #(EpiceaInPharo40 EpiceaBrowsersTests).
	].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 12/4/2015 00:41'!
baseline71p5: spec
	<version: '7.1.p5-baseline'>
	"Specialized baseline for Pharo 5"

	spec for: #'pharo5.x' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu';
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaBrowsers' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaTests' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaBrowsersTests' with: [
				spec requires: #(EpiceaBrowsers EpiceaTests) ];
			package: 'EpiceaBenchmarks' with: [ 
				spec requires: #(EpiceaBrowsersTests SMark) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(EpiceaBrowsersTests) ];
			package: 'EpiceaSUnit' with: [
				spec requires: #(EpiceaBrowsersTests) ];
			package: 'Hiedra';
			package: 'EpiceaHiedra' with: [
				spec requires: #(EpiceaBrowsers Hiedra) ].

		spec group: 'default' overrides: #(EpiceaBrowsers EpiceaBrowsersTests).
		spec group: 'core' overrides: #(EpiceaBrowsers).
		spec group: 'benchmarks' with: #(EpiceaBrowsers EpiceaBrowsersTests EpiceaBenchmarks).
		spec group: 'komitter' with: #(EpiceaBrowsers EpiceaBrowsersTests EpiceaKomitter).
		spec group: 'hiedra' with: #(EpiceaBrowsers EpiceaBrowsersTests EpiceaHiedra).
		spec group: 'sunit' with: #(EpiceaBrowsers EpiceaBrowsersTests EpiceaSUnit).
	].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 12/7/2015 19:22'!
baseline72p4: spec
	<version: '7.2.p4-baseline'>
	"Specialized baseline for Pharo 4"

	spec for: #'pharo4.x' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.
		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu' with: [
				spec requires: #(STON) ]; "Ston was not integrated in Pharo 40"
			package: 'OmbuTests' with: [
				spec requires: #(Ombu) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaBrowsers' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaTests' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaBrowsersTests' with: [
				spec requires: #(EpiceaBrowsers EpiceaTests) ];
			package: 'EpiceaInPharo40' with: [
				spec requires: #(EpiceaBrowsers) ].

		spec group: 'default' with: #(EpiceaInPharo40 EpiceaBrowsersTests OmbuTests).
	].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 12/7/2015 19:23'!
baseline72p5: spec
	<version: '7.2.p5-baseline'>
	"Specialized baseline for Pharo 5"

	spec for: #'pharo5.x' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline64SMark: spec.

		spec postLoadDoIt: #version60PostLoad.

		spec 
			package: 'Ombu';
			package: 'OmbuTests' with: [
				spec requires: #(Ombu) ];
			package: 'Epicea' with: [
				spec requires: #(Ombu) ];
			package: 'EpiceaBrowsers' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaTests' with: [
				spec requires: #(Epicea) ];
			package: 'EpiceaBrowsersTests' with: [
				spec requires: #(EpiceaBrowsers EpiceaTests) ];
			package: 'EpiceaBenchmarks' with: [ 
				spec requires: #(EpiceaBrowsersTests SMark) ];
			package: 'EpiceaKomitter' with: [
				spec requires: #(EpiceaBrowsersTests) ];
			package: 'EpiceaSUnit' with: [
				spec requires: #(EpiceaBrowsersTests) ];
			package: 'Hiedra';
			package: 'EpiceaHiedra' with: [
				spec requires: #(EpiceaBrowsers Hiedra) ].

		spec group: 'default' overrides: #(EpiceaBrowsers EpiceaBrowsersTests OmbuTests).
		spec group: 'core' overrides: #(EpiceaBrowsers).
		spec group: 'benchmarks' with: #(EpiceaBrowsers EpiceaBrowsersTests OmbuTests EpiceaBenchmarks).
		spec group: 'komitter' with: #(EpiceaBrowsers EpiceaBrowsersTests OmbuTests EpiceaKomitter).
		spec group: 'hiedra' with: #(EpiceaBrowsers EpiceaBrowsersTests OmbuTests EpiceaHiedra).
		spec group: 'sunit' with: #(EpiceaBrowsers EpiceaBrowsersTests OmbuTests EpiceaSUnit).
	].
! !

!ConfigurationOfEpicea methodsFor: 'accessing' stamp: 'MartinDias 8/13/2013 14:02'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfEpicea methodsFor: 'tags' stamp: 'MartinDias 12/7/2015 19:23'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'pharo4.x' version: '7.2.p4-baseline'.
	spec for: #'pharo5.x' version: '7.2.p5-baseline'.
! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/17/2014 13:13'!
hasModifiedMark: aPackageName

	^ (self mcWorkingCopyOf: aPackageName) modified! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 2/16/2014 23:27'!
isEpiceaAlreadyLoaded

	^ Smalltalk hasClassNamed: #EpMonitor! !

!ConfigurationOfEpicea methodsFor: 'accessing' stamp: 'MartinDias 8/13/2013 14:12'!
mainRepositoryUrlString
	^ 'http://smalltalkhub.com/mc/MartinDias/Epicea/main'! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/17/2014 13:13'!
mcWorkingCopyOf: aPackageName

	^ MCWorkingCopy allManagers detect: [ :each | each package name = aPackageName ]! !

!ConfigurationOfEpicea methodsFor: 'accessing' stamp: 'MartinDias 12/5/2015 17:26'!
project

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:12'!
revertAllModified: somePackageNames

	somePackageNames 
		do: [ :name |
			(self hasModifiedMark: name)
				ifTrue: [ 
					Gofer new
						url: 'http://smalltalkhub.com/mc/Pharo/Pharo30/main';
						package: name;
						revert ] ]! !

!ConfigurationOfEpicea methodsFor: 'tags' stamp: 'MartinDias 2/2/2016 00:43'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'pharo4.x' version: '7.5.p4'.
	spec for: #'pharo5.x' version: '7.5.p5'.
! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 2/16/2014 23:35'!
stopLogging
	"Stop and reset recording IDE events"

	(Smalltalk classNamed: #EpMonitor) reset! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/17/2014 13:43'!
unmarkAsModified: somePackageNames
	"HACK: Unmark as modified the foreign packages where Epicea overrides methods. Not needed anymoew: I discovered that the same effect can be obtained just suffixing the protocols with -override."

	somePackageNames do: [ :name |
		(self mcWorkingCopyOf: name) modified: false ]! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/10/2013 23:18'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec 
			description: 'First public version, migrated from sandbox repository.';
			author: 'Martin Dias';
			timestamp: '2013-08-13'.
		
		spec
			package: 'Epicea'  with: 'Epicea-MartinDias.94';
			package: 'Ombu' with: 'Ombu-MartinDias.12';			
			project: 'Phexample' with: #development ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/10/2013 23:18'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec 
			description: 'Visualise comment in nice morphs. Text search is broken. Added some tests.';
			author: 'Martin Dias';
			timestamp: '2013-08-14'.
		
		spec
			package: 'Epicea'  with: 'Epicea-MartinDias.115';
			package: 'Ombu' with: 'Ombu-MartinDias.12';			
			project: 'Phexample' with: #development ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/17/2013 14:45'!
version12: spec
	<version: '1.2' imports: #('1.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Version showed at ESUG Innovation Technology Awards. Image used: Pharo-30381.'.
		spec author: 'MartinDias'.
		spec timestamp: '9/10/2013 09:57'.
		spec project: 'Phexample' with: '1.2'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.96';
			package: 'Epicea' with: 'Epicea-MartinDias.229'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/25/2013 14:09'!
version13: spec
	<version: '1.3' imports: #('1.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Support STON persistence and other improvements.'.
		spec author: 'MartinDias'.
		spec timestamp: '25/09/2013'.
		spec project: 'Phexample' with: '1.2'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.106';
			package: 'Epicea' with: 'Epicea-MartinDias.256'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/23/2013 17:49'!
version14: spec
	<version: '1.4' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'A lot of visual improvements and multiple fixes.'.
		spec author: 'MartinDias'.
		spec timestamp: '22/10/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.110';
			package: 'Epicea' with: 'Epicea-MartinDias.329'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/24/2013 13:09'!
version15: spec
	<version: '1.5' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Just fixed Undo and Redo operations of previous version.'.
		spec author: 'MartinDias'.
		spec timestamp: '24/10/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.110';
			package: 'Epicea' with: 'Epicea-MartinDias.330'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/25/2013 16:02'!
version16: spec
	<version: '1.6' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Added icons to contextual menu.
			- Some internal refactorings.
			- Some minor fixes.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '25/10/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.110';
			package: 'Epicea' with: 'Epicea-MartinDias.338'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/13/2013 18:30'!
version17: spec
	<version: '1.7' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- ChangeSet importer.
			- Working in Pharo #30570.
				- Migrated to new Spec.
				- Some extensions were integrated.
			- More tests.
			- General clean up.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '13/11/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.120';
			package: 'Epicea' with: 'Epicea-MartinDias.417'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/14/2013 16:54'!
version18: spec
	<version: '1.8' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Created File Reader Service for ChangeSet importer.
			- Working in Pharo #30572.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/11/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.120';
			package: 'Epicea' with: 'Epicea-MartinDias.425'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 1/14/2014 17:39'!
version19: spec
	<version: '1.9' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Some fixes
			- Working in Pharo #30695.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/01/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.124';
			package: 'Epicea' with: 'Epicea-MartinDias.469'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/11/2014 16:25'!
version20: spec
	<version: '2.0' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Ready for preliminar study.
			- New: Sessions Browser.
			- Working in Pharo #30753.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '10/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.483'.
			
		spec
			preLoadDoIt: #version20PreLoad;
			postLoadDoIt: #version20PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:13'!
version20PostLoad

	self unmarkAsModified: {'Tools'. 'Monticello'. 'MonticelloGUI'. 'NautilusRefactoring'. 'OpalCompiler-Core'}.
	self version20StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 2/16/2014 23:27'!
version20PreLoad

	self isEpiceaAlreadyLoaded ifTrue: [
		self stopLogging ]! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 4/14/2014 17:07'!
version20StartLogging
	"Start recording IDE events"

	#EpSessionStoreStrategy asClass 
		defaultBaseDirectoryLocator: FileLocator preferences / 'pharo' / 'epicea-study-1'.
	
	#EpMonitor asClass current enable.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/11/2014 16:25'!
version21: spec
	<version: '2.1' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Like 2.0 but working better with Komitter.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '11/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.485'.
			
		spec
			preLoadDoIt: #version20PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:13'!
version21PostLoad

	self unmarkAsModified: {'Tools'. 'Monticello'. 'NautilusRefactoring'. 'OpalCompiler-Core'}.
	self version20StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/11/2014 20:39'!
version22: spec
	<version: '2.2' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Fixed bugs with refactorings.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '11/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.488'.
			
		spec
			preLoadDoIt: #version20PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/12/2014 14:18'!
version23: spec
	<version: '2.3' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Same code as 2.2, but safer for upgrading from previous versions.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '12/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.488'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:05'!
version23OverridenPackageNames

	^ {'Tools'. 'Monticello'. 'MonticelloGUI'. 'NautilusRefactoring'. 'OpalCompiler-Core'}! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:07'!
version23PreLoad

	self isEpiceaAlreadyLoaded ifTrue: [
		self stopLogging.
		self revertAllModified: self version23OverridenPackageNames ]! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/13/2014 16:51'!
version24: spec
	<version: '2.4' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Log test suite runs.
			- Fix bug when Author is not set.
			- Fix/workaround for bug in class modification.
			- Added a new view for EpLogBrowser.
			- Show ombu filename in EpLogBrowser.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '13/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.494'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/14/2014 11:12'!
version25: spec
	<version: '2.5' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Ombu: Fix bug while parsing files.
			- Ombu: Tolerate Ston parsing errors.
			- Some visual changes on Log Browser and Session Browser.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.127';
			package: 'Epicea' with: 'Epicea-MartinDias.504'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/14/2014 13:48'!
version26: spec
	<version: '2.6' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Ombu: Fix Ston materialization of RPackageTags.
			- Epicea: Added a button to absent entry, enabling navigation between ombu files.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.505'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/19/2014 13:47'!
version27: spec
	<version: '2.7' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Fix: EpMethodRemoval was not holding the real protocol.
			- Feature: Enable multiple selection in items list.
			- Clean up: removed unused code
			- Fix: undo and redo for multiple selection
			'.
		spec author: 'MartinDias'.
		spec timestamp: '19/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.511'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/19/2014 14:45'!
version28: spec
	<version: '2.8' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Minor visual improvements in Browser:
			- remember how many pages where fetched.
			- set a title to the items menu
			'.
		spec author: 'MartinDias'.
		spec timestamp: '19/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.513'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/19/2014 18:15'!
version29: spec
	<version: '2.9' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Fixed 2 failing tests. Now everything is green :)
			'.
		spec author: 'MartinDias'.
		spec timestamp: '19/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.514'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/21/2014 16:18'!
version30: spec
	<version: '3.0' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Update for Pharo 30777.
			- Increased browser initial #pageSize from 20 to 30.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '21/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.516'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 3/3/2014 18:30'!
version31: spec
	<version: '3.1' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Added "any code change" filter.
			- Now only EpEntryItems in the selection are taken into account for menu actions.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '03/03/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.129';
			package: 'Epicea' with: 'Epicea-MartinDias.529'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 3/4/2014 18:49'!
version32: spec
	<version: '3.2' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Order the entries for redo and undo operations using the timestamp. 
				(Much better than using the user selection order).
			- Implemented #asEpiceaRingDefinition in metamodel and ring definitions. 
				The advantages are: 
				- Store package name always, instead of either nil or the RPackage.
				- Huge speed up in ChangeSet importation since it was storing parent of the methods.
				- It is possible to Redo or Undo an event imported from a ChangeSet (it was almost impossible).
				- Also do not store #passive annotation on each method, which saves a bit of space.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '04/03/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.129';
			package: 'Epicea' with: 'Epicea-MartinDias.531'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/15/2014 17:40'!
version33: spec
	<version: '3.3' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '15/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.149';
			package: 'Epicea' with: 'Epicea-MartinDias.576'. ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:06'!
version33OverridenPackageNames

	^ {'Tools'. 'Monticello'. 'NautilusRefactoring'. 'OpalCompiler-Core'. 'SUnit-Core'}! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:13'!
version33PostLoad

	self unmarkAsModified: self version33OverridenPackageNames.
	self version33StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:07'!
version33PreLoad

	self isEpiceaAlreadyLoaded ifTrue: [
		self stopLogging.
		self revertAllModified: self version33OverridenPackageNames ]! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 4/14/2014 17:06'!
version33StartLogging
	"Start recording IDE events"

	#OmSessionStore asClass 
		defaultBaseDirectoryLocator: FileLocator preferences / 'pharo' / 'epicea-3.3'.
	
	#EpMonitor asClass current enable.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/16/2014 18:12'!
version34: spec
	<version: '3.4' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '16/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.153';
			package: 'Epicea' with: 'Epicea-MartinDias.578'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/17/2014 14:43'!
version35: spec
	<version: '3.5' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '17/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.580'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/17/2014 17:02'!
version36: spec
	<version: '3.6' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '17/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.582'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/23/2014 13:25'!
version37: spec
	<version: '3.7' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '23/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.583'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 5/3/2014 21:15'!
version38: spec
	<version: '3.8' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Added a group for World Menu'.
		spec author: 'MartinDias'.
		spec timestamp: '03/05/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.585'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 5/27/2014 15:45'!
version39: spec
	<version: '3.9' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* New feature: File Out to Ombu
	* New feature: File Out to ChangeSet
	* Bug fix: Issues when importing ChangeSet
	* New feature: Test that overriding external methods in system are right
	* Bug fix: It was loosing class-side definition modifications.
	* Clean up: Removed tons of unused classes and methods.
	* New feature: Show class-side definitions in content tab.
	* Others
		'.
		spec author: 'MartinDias'.
		spec timestamp: '27/05/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.155';
			package: 'Epicea' with: 'Epicea-MartinDias.610'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 6/5/2014 14:49'!
version40: spec
	<version: '4.0' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* Session browser: sort by clicking on columns
	* OmFileStores are lazy.
'.
		spec author: 'MartinDias'.
		spec timestamp: '05/06/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.161';
			package: 'Epicea' with: 'Epicea-MartinDias.617'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/17/2014 15:28'!
version41: spec
	<version: '4.1' imports: #('4.1-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* The base for files is a FileLocator instead of a FileReference. This way it should tolerate sending an image from one computer to another with epicea already enabled inside.
	* Support for multiple themes, e.g. the DarkTheme.
'.
		spec author: 'MartinDias'.
		spec timestamp: '17/07/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.162';
			package: 'Epicea' with: 'Epicea-MartinDias.620'. ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 6/5/2014 17:17'!
version41PostLoad

	self unmarkAsModified: self version33OverridenPackageNames.
	self version41StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 6/5/2014 17:16'!
version41StartLogging
	"Start recording IDE events"

	#OmSessionStore asClass 
		defaultBaseLocator: FileLocator preferences / 'pharo' / 'epicea-3.3'.
	
	#EpMonitor asClass current enable.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/31/2014 17:32'!
version42: spec
	<version: '4.2' imports: #('4.1-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* Put an upper bound to number of entries displayed in the drag&drop morph.
	* Clean-up. Several passes of CodeCritics. 
	* Use standard Pharo icons in browser.
	* Fixed other minor issues.
'.
		spec author: 'MartinDias'.
		spec timestamp: '31/07/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.163';
			package: 'Epicea' with: 'Epicea-MartinDias.627'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 8/13/2014 11:19'!
version43: spec
	<version: '4.3' imports: #('4.1-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* Removing uses of RGFactory since it is being deprecated in Pharo 4. 
'.
		spec author: 'MartinDias'.
		spec timestamp: '13/08/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.163';
			package: 'Epicea' with: 'Epicea-MartinDias.628'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 8/21/2014 12:22'!
version44: spec
	<version: '4.4' imports: #('4.1-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* Mainly some cosmetic improvements
'.
		spec author: 'MartinDias'.
		spec timestamp: '21/08/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.163';
			package: 'Epicea' with: 'Epicea-MartinDias.632'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/27/2014 17:14'!
version45: spec
	<version: '4.5' imports: #('4.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Working in Pharo 30859 and 40330'.
		spec author: 'MartinDias'.
		spec timestamp: '10/27/2014 17:12'.
		spec project: 'STON' with: '0.3-baseline'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.166';
			package: 'Epicea' with: 'Epicea-MartinDias.644'. ].

	spec for: #'pharo3.0.x' do: [
		spec package: 'EpiceaInPharo30' with: 'EpiceaInPharo30-MartinDias.1'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 12/12/2014 15:47'!
version46: spec
	<version: '4.6' imports: #('4.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Prepared for integration into Pharo 4'.
		spec author: 'MartinDias'.
		spec timestamp: '12/12/2014 17:12'.
		spec project: 'STON' with: '0.10'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.171';
			package: 'Epicea' with: 'Epicea-MartinDias.670'. ].

	spec for: #'pharo3.0.x' do: [
		spec package: 'EpiceaInPharo30' with: 'EpiceaInPharo30-MartinDias.1'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 12/15/2014 18:47'!
version47: spec
	<version: '4.7' imports: #('4.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Removed overrides to system packages (buh).
	* Prepared for integration into Pharo 4.'.
		spec author: 'MartinDias'.
		spec timestamp: '15/12/2014 18:12'.
		spec project: 'STON' with: '0.10'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.173';
			package: 'Epicea' with: 'Epicea-MartinDias.676'. ].

	spec for: #'pharo3.0.x' do: [
		spec package: 'EpiceaInPharo30' with: 'EpiceaInPharo30-MartinDias.1'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/3/2015 12:22'!
version48: spec
	<version: '4.8' imports: #('4.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Added a #triggering group.
	* Workaround for tolerating OS changes in file references.
	* Fixed "Browse" for absent methods.'.
		spec author: 'MartinDias'.
		spec timestamp: '2015-01-13 19:32'.
		spec project: 'STON' with: '0.10'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.175';
			package: 'Epicea' with: 'Epicea-MartinDias.678'. ].

	spec for: #'pharo3.0.x' do: [
		spec package: 'EpiceaInPharo30' with: 'EpiceaInPharo30-MartinDias.1'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/3/2015 12:21'!
version49: spec
	<version: '4.9' imports: #('4.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Fixed bug when running tests from Nautilus.'.
		spec author: 'MartinDias'.
		spec timestamp: '2015-04-03 12:20'.
		spec project: 'STON' with: '0.10'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.176';
			package: 'Epicea' with: 'Epicea-MartinDias.681'. ].

	spec for: #'pharo3.0.x' do: [
		spec package: 'EpiceaInPharo30' with: 'EpiceaInPharo30-MartinDias.1'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/7/2015 17:34'!
version50: spec
	<version: '5.0' imports: #('5.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Remove tolerance for corrupt files. Not needed and error-prone.
	* Fix for Ombu in Linux (flush after writing a new entry).
	* Stop support for Pharo 30. Still not working in Pharo 50, but I created a compatibility package for Pharo 40 which will help.
	* Some minor clean-ups.
	* Clean up and small fix for importing .changes
	* Added extension methods from EpiceaSorter
	* Improved LogBuilder (for tests)
	* Added concept of secondary color to log items
	* #imageName has been deprecated in Pharo 50 => changing to a selector that works in both 40 and 50.
	* Fixed #methodRemoved:'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-07-07 17:34'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.180';
			package: 'Epicea' with: 'Epicea-MartinDias.694';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.3'. ].

! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/8/2015 18:43'!
version50OverridenPackageNames

	^ {'Epicea'. 'Jobs'. 'Tool-Base'. 'Monticello'. 'NautilusRefactoring'. 'CodeImport'. 'SUnit-Core'}! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/7/2015 16:39'!
version50PostLoad

	self unmarkAsModified: self version50OverridenPackageNames.
	"self version50StartLogging."! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/7/2015 16:13'!
version50StartLogging
	"Start recording IDE events in default directory, i.e. OmSessionStore defaultBaseLocator"

	#EpMonitor asClass current enable.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/8/2015 18:38'!
version51: spec
	<version: '5.1' imports: #('5.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Working in both Pharo 40 and current Pharo 50 (50161)
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-07-08 18:37'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.180';
			package: 'Epicea' with: 'Epicea-MartinDias.704';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.11';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.8'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/9/2015 11:46'!
version52: spec
	<version: '5.2' imports: #('5.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Version 5.1 was not logging MC save events in Pharo 50.
	* Working in both Pharo 40 and current Pharo 50 (50162).
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-07-09 11:45'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.180';
			package: 'Epicea' with: 'Epicea-MartinDias.706';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.11';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.9'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/10/2015 11:00'!
version53: spec
	<version: '5.3' imports: #('5.1-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Workaround for RewriteTool.
	* Working in both Pharo 40 and current Pharo 50 (50162).
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-07-10 00:44'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.180';
			package: 'Epicea' with: 'Epicea-MartinDias.706';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.11';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.10';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/14/2015 09:55'!
version54: spec
	<version: '5.4' imports: #('5.4-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Set recording directory to user preferences directory, as it was in previous versions.
	* Working in both Pharo 40 and current Pharo 50 (50170).
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-07-14 09:55'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.180';
			package: 'Epicea' with: 'Epicea-MartinDias.706';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.11';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.10';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/14/2015 10:09'!
version54PostLoad

	self unmarkAsModified: self version50OverridenPackageNames.
	self version54StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/14/2015 11:20'!
version54StartLogging
	"Start recording IDE events if in interactive mode"

	Smalltalk isInteractive ifTrue: [
		#OmSessionStore asClass 
			defaultBaseLocator: FileLocator preferences / 'pharo' / 'epicea-5.4-sessions'.
		
		#EpMonitor asClass current enable ]! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/20/2015 17:47'!
version55: spec
	<version: '5.5' imports: #('5.4-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Fix Redo and Undo operations in Pharo50.
	* Minor fix in item colors.
	* Working in both Pharo 40 and current Pharo 50 (50177).
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-07-20 17:36'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.180';
			package: 'Epicea' with: 'Epicea-MartinDias.707';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.11';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.11';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/22/2015 15:28'!
version56: spec
	<version: '5.6' imports: #('5.4-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Fix wrong use of FileLocator>>path.
	* Working in both Pharo 40 and current Pharo 50 (50182).
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-07-22 15:20'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.181';
			package: 'Epicea' with: 'Epicea-MartinDias.708';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.11';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.11';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 8/24/2015 16:08'!
version57: spec
	<version: '5.7' imports: #('5.4-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Fix DNU in Pharo 50265. No need to register to FileServices, so remove methods.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-08-24 16:06'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.181';
			package: 'Epicea' with: 'Epicea-MartinDias.709';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.11';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-VincentBlondeau.12';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 8/24/2015 16:23'!
version58: spec
	<version: '5.8' imports: #('5.4-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* You need to register to FileServices in Pharo 4.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-08-24 16:06'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.181';
			package: 'Epicea' with: 'Epicea-MartinDias.709';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.12';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-VincentBlondeau.12';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/9/2015 21:59'!
version59: spec
	<version: '5.9' imports: #('5.9-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Changed initial ombu files directory to "<preferences>/epicea-sessions"
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-09-09 21:59'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.181';
			package: 'Epicea' with: 'Epicea-MartinDias.720';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.12';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-VincentBlondeau.12';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 9/9/2015 21:54'!
version59PostLoad

	self unmarkAsModified: self version50OverridenPackageNames.
	self version59StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 9/9/2015 21:45'!
version59StartLogging
	"Start recording IDE events if in interactive mode"

	Smalltalk isInteractive ifTrue: [
		(Smalltalk classNamed: #OmSessionStore)
			defaultBaseLocator: FileLocator preferences / 'pharo' / 'epicea-sessions'.
		
		(Smalltalk classNamed: #EpMonitor) current enable ]! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/15/2015 18:18'!
version60: spec
	<version: '6.0' imports: #('6.0-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Add EpCategoryRename event. Update visitors accordingly.
	* Fix override to parseNextDeclaration.
	* Remove overridden method "MCVersionLoader>>load", it has since been added to MCVersionLoader and is not needed anymore.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-09-15 18:14'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.181';
			package: 'Epicea' with: 'Epicea-SkipLentz.722';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.12';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.15';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'SkipLentz 9/14/2015 13:54'!
version60PostLoad
	self version60StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 9/14/2015 12:41'!
version60StartLogging
	"Start recording IDE events"

	(Smalltalk classNamed: #OmSessionStore)
		defaultBaseLocator: FileLocator imageDirectory / 'epicea-sessions'.
		
	(Smalltalk classNamed: #EpMonitor) current enable! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'SkipLentz 9/28/2015 15:16'!
version61: spec
	<version: '6.1' imports: #('6.1-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Add tests for redo and undo functionality, currently disabled.
	* Remove calls to deprecated Announcer messages.
'.
	
		spec author: 'SkipLentz'.
		spec timestamp: '2015-09-28 15:12'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.181';
			package: 'Epicea' with: 'Epicea-SkipLentz.737';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.12';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-SkipLentz.16';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/28/2015 21:49'!
version62: spec
	<version: '6.2' imports: #('6.1-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Minor update: Implemented #visitCodeChange: in EpTestVisitor because ReleaseTest doesn''t like it else.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-09-28 21:45'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.181';
			package: 'Epicea' with: 'Epicea-MartinDias.738';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.12';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-SkipLentz.16';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/29/2015 22:37'!
version63: spec
	<version: '6.3' imports: #('6.1-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Clean up with Code Critics.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-09-28 22:37'.
		spec project: 'STON' with: '0.14'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.183';
			package: 'Epicea' with: 'Epicea-MartinDias.742';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.12';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-SkipLentz.16';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/22/2015 15:36'!
version64: spec
	<version: '6.4' imports: #('6.4-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Adding benchmarks group.
	* Enhancing World menu entries
	* Fixed some undo cases.
	* Updated test to do not load external project but a mock.
	* Migrated to Pharo 5 (some deprecated method).
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-10-22 15:28'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MartinDias.755';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.12';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-SkipLentz.16';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MD 11/9/2015 21:59'!
version65: spec
	<version: '6.5' imports: #('6.5-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Split SUnit support from core package to an optional one (EpiceaSUnit).
	* Fixed World menu entries for Pharo 40.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-11-09 21:54'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MartinDias.759';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.14';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-SkipLentz.16';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/12/2015 14:42'!
version66: spec
	<version: '6.6' imports: #('6.6-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Split tests from core package to an optional one (EpiceaTests).
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-11-12 14:41'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MartinDias.760';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.1';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.14';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-SkipLentz.16';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/12/2015 18:45'!
version67: spec
	<version: '6.7' imports: #('6.6-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Experiment: disable redo and undo tests because they seem to cause a problem during integration.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-11-12 18:44'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-SkipLentz.761';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.2';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.14';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-SkipLentz.16';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/24/2015 23:24'!
version68: spec
	<version: '6.8' imports: #('6.6-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Several fixes to undo and redo visitors.
	* Fix in display building from Gustavo (thanks!!).
	* Removed some (and last remaining) unnecessary overrides in Pharo.
	* Removed some unused methods in models.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-11-24 23:11'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MartinDias.767';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.2';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.14';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.17';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MD 11/25/2015 22:40'!
version69: spec
	<version: '6.9' imports: #('6.6-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Add #asEpiceaRingDefinition to TClass as explicit requirement, since it was defined in Class and in Trait. This is a requirement in Pharo 5.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-11-25 22:40'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MD.768';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.2';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.14';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.17';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/25/2015 22:52'!
version70: spec
	<version: '7.0' imports: #('6.6-baseline')>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: '
	* Add #asEpiceaRingDefinition to TApplyingOnClassSide as explicit requirement, since it was defined in Class and in Trait. This is a requirement in Pharo 5.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-11-25 22:52'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MartinDias.769';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.2';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.14';
			package: 'EpiceaInPharo50' with: 'EpiceaInPharo50-MartinDias.17';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 12/4/2015 01:09'!
version71p4: spec
	<version: '7.1.p4' imports: #('7.1.p4-baseline')>

	spec for: #'pharo4.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Split Model and UI.
	* Merged EpiceaForPharo50 into Epicea.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-12-04 01:01'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MartinDias.773';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.3';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.3';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.1';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.15';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 12/4/2015 01:05'!
version71p5: spec
	<version: '7.1.p5' imports: #('7.1.p5-baseline')>

	spec for: #'pharo5.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Split Model and UI.
	* Merged EpiceaForPharo50 into Epicea.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-12-04 01:01'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.187';
			package: 'Epicea' with: 'Epicea-MartinDias.773';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.3';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.3';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.1';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 12/7/2015 19:43'!
version72p4: spec
	<version: '7.2.p4' imports: #('7.2.p4-baseline')>

	spec for: #'pharo4.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Split tests in Ombu.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-12-07 19:42'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.188';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.1';
			package: 'Epicea' with: 'Epicea-MartinDias.773';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.3';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.3';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.1';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.15';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 12/7/2015 19:44'!
version72p5: spec
	<version: '7.2.p5' imports: #('7.2.p5-baseline')>

	spec for: #'pharo5.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Split tests in Ombu.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2015-12-07 19:42'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.188';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.1';
			package: 'Epicea' with: 'Epicea-MartinDias.773';
			package: 'EpiceaTests' with: 'EpiceaTests-MartinDias.3';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.3';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.1';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 1/29/2016 02:10'!
version73p4: spec
	<version: '7.3.p4' imports: #('7.2.p4-baseline')>

	spec for: #'pharo4.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Remove repeated trait methods in users (bug in refactoring tools).
	* Add EpMonticelloVersionsLoad>>{=,hash} for comparing version load events.
	* New enumeration methods in EpLog.
	* Properly dispose of EpLogTestResource in EpLogTest.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2016-01-29 02:04'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.188';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.1';
			package: 'Epicea' with: 'Epicea-SkipLentz.775';
			package: 'EpiceaTests' with: 'EpiceaTests-SkipLentz.5';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.4';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.2';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.15';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 1/29/2016 02:10'!
version73p5: spec
	<version: '7.3.p5' imports: #('7.2.p5-baseline')>

	spec for: #'pharo5.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Remove repeated trait methods in users (bug in refactoring tools).
	* Add EpMonticelloVersionsLoad>>{=,hash} for comparing version load events.
	* New enumeration methods in EpLog.
	* Properly dispose of EpLogTestResource in EpLogTest.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2016-01-29 02:04'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.188';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.1';
			package: 'Epicea' with: 'Epicea-SkipLentz.775';
			package: 'EpiceaTests' with: 'EpiceaTests-SkipLentz.5';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.4';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.2';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/1/2016 04:49'!
version74p4: spec
	<version: '7.4.p4' imports: #('7.2.p4-baseline')>

	spec for: #'pharo4.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Adding system settings to enabled and disable the monitor, replacing the World Menu switch.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2016-02-01 04:48'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.189';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.1';
			package: 'Epicea' with: 'Epicea-MartinDias.776';
			package: 'EpiceaTests' with: 'EpiceaTests-SkipLentz.5';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.10';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.2';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.15';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/1/2016 04:50'!
version74p5: spec
	<version: '7.4.p5' imports: #('7.2.p5-baseline')>

	spec for: #'pharo5.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Adding system settings to enabled and disable the monitor, replacing the World Menu switch.
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2016-02-01 04:48'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.189';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.1';
			package: 'Epicea' with: 'Epicea-MartinDias.776';
			package: 'EpiceaTests' with: 'EpiceaTests-SkipLentz.5';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.10';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.2';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/2/2016 00:41'!
version75p4: spec
	<version: '7.5.p4' imports: #('7.2.p4-baseline')>

	spec for: #'pharo4.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Create random sufixes to test ombu files (required in Windows)
	* Use #closeForWriting on file store (needed by some tests to run in Windows)
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2016-02-02 12:41'.
		spec project: 'STON' with: '0.14'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.190';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.2';
			package: 'Epicea' with: 'Epicea-MartinDias.776';
			package: 'EpiceaTests' with: 'EpiceaTests-SkipLentz.5';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.10';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.2';
			package: 'EpiceaInPharo40' with: 'EpiceaInPharo40-MartinDias.15';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/2/2016 00:42'!
version75p5: spec
	<version: '7.5.p5' imports: #('7.2.p5-baseline')>

	spec for: #'pharo5.x' do: [
		spec blessing: #'stable'.
		spec description: '
	* Create random sufixes to test ombu files (required in Windows)
	* Use #closeForWriting on file store (needed by some tests to run in Windows)
'.
	
		spec author: 'MartinDias'.
		spec timestamp: '2016-02-02 12:41'.
		spec project: 'SMark' with: '1.0.1'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.190';
			package: 'OmbuTests' with: 'OmbuTests-MartinDias.2';
			package: 'Epicea' with: 'Epicea-MartinDias.776';
			package: 'EpiceaTests' with: 'EpiceaTests-SkipLentz.5';
			package: 'EpiceaBrowsers' with: 'EpiceaBrowsers-MartinDias.10';
			package: 'EpiceaBrowsersTests' with: 'EpiceaBrowsersTests-MartinDias.2';
			package: 'Hiedra' with: 'Hiedra-MartinDias.136';
			package: 'EpiceaHiedra' with: 'EpiceaHiedra-MD.11';
			package: 'EpiceaBenchmarks' with: 'EpiceaBenchmarks-MartinDias.4';
			package: 'EpiceaKomitter' with: 'EpiceaKomitter-MartinDias.13';
			package: 'EpiceaSUnit' with: 'EpiceaSUnit-MartinDias.4'. ].
! !
